[![pre-commit](https://github.com/finsberg/pygscholar/actions/workflows/pre-commit.yml/badge.svg)](https://github.com/finsberg/pygscholar/actions/workflows/pre-commit.yml)
[![PyPI version](https://badge.fury.io/py/pygscholar.svg)](https://badge.fury.io/py/pygscholar)
[![CI](https://github.com/finsberg/pygscholar/actions/workflows/main.yml/badge.svg)](https://github.com/finsberg/pygscholar/actions/workflows/main.yml)
[![codecov](https://codecov.io/gh/finsberg/pygscholar/branch/main/graph/badge.svg?token=IUZ9HMIBFA)](https://codecov.io/gh/finsberg/pygscholar)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
# PyGScholar

Tool for working extracting statistics from Google scholar built upon [`scholarly`](https://scholarly.readthedocs.io)

Imagine you have a department full of researchers and you want to keep track of the most recent or most cited papers in the department, or that you simply want to track yourself, then this package might be what you need.


## Install
Install with pip
```
python -m pip install pygscholar
```

## Documentation
TODO: Setup gh pages with Sphinx

## License
MIT
